import axios from 'axios'
import {Message} from 'element-ui'
import {
	getToken,
	setToken
} from './auth.js'
import qs from 'qs'

const service = axios.create({
	baseURL: process.env.VUE_APP_BASE_API, // api的base_url
	timeout: 5000,
	headers: {
		'Content-Type': 'application/x-www-form-urlencoded'
	},
	transformRequest: [function(data) {
		return qs.stringify(data)
	}]
})

service.interceptors.request.use(
	config => {
		if (getToken()) {
			config.headers['A-Token'] = getToken()
		}
		return config
	},
	error => {
		Promise.reject(error)
	}
)

// respone interceptor
service.interceptors.response.use(
	response => {
		if (response.data.code === 1) {
			if (response.data.refresh_token) {
				if (response.data.refresh_token !== getToken()) {
					setToken(response.data.refresh_token);
				}
			}
			return response;
		} else if (response.data.code === 401) {
			Message({
				message: response.data.msg,
				type: 'error',
			})
		}else{
			Message({
				message: response.data.msg,
				type: 'error',
			})
		}
	
	},
	error => {
		Message({
			message: error.message,
			type: 'error',
		})
		return Promise.reject(error)
	}
)

export default service
